@@ -128,8 +128,8 @@ daemon_start(Options) when is_list(Options) ->
 daemon_init(Config) when is_record(Config, config), 
                          is_pid(Config#config.parent_pid) ->
     process_flag(trap_exit, true),
-    UdpOptions = prepare_daemon_udp(Config),
-    case catch gen_udp:open(Config#config.udp_port, UdpOptions) of
+    {Port, UdpOptions} = prepare_daemon_udp(Config),
+    case catch gen_udp:open(Port, UdpOptions) of
         {ok, Socket} ->
             {ok, ActualPort} = inet:port(Socket),
             proc_lib:init_ack({ok, self()}),
@@ -157,7 +157,7 @@ prepare_daemon_udp(#config{udp_port = Port, udp_options = UdpOptions} = Config)
     case lists:keymember(fd, 1, UdpOptions) of
         true ->
             %% Use explicit fd
-            UdpOptions;
+            {Port, UdpOptions};
         false ->
             %% Use fd from setuid_socket_wrap, such as -tftpd_69
             InitArg = list_to_atom("tftpd_" ++ integer_to_list(Port)),
@@ -165,7 +165,7 @@ prepare_daemon_udp(#config{udp_port = Port, udp_options = UdpOptions} = Config)
                 {ok, [[FdStr]] = Badarg} when is_list(FdStr) ->
                     case catch list_to_integer(FdStr) of
                         Fd when is_integer(Fd) ->
-                            [{fd, Fd} | UdpOptions];
+                            {0, [{fd, Fd} | lists:keydelete(ip, 1, UdpOptions)]};
                         {'EXIT', _} ->
                             Text = lists:flatten(io_lib:format("Illegal prebound fd ~p: ~p", [InitArg, Badarg])),
                             print_debug_info(Config, daemon, open, ?ERROR(open, undef, Text, "")),
@@ -176,7 +176,7 @@ prepare_daemon_udp(#config{udp_port = Port, udp_options = UdpOptions} = Config)
                     print_debug_info(Config, daemon, open, ?ERROR(open, undef, Text, "")),
                     exit({badarg, {prebound_fd, InitArg, Badarg}});
                 error ->
-                    UdpOptions
+                    {Port, UdpOptions}
             end
     end.
 
