@@ -12,7 +12,7 @@ value({Token, _Line}) ->
 value({_Token, _Line, Value}) ->
 	Value.
 
--file("/net/isildur/ldisk/daily_build/18_prebuild_master-opu_o.2015-06-23_20/otp_src_18/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/net/isildur/ldisk/daily_build/18_prebuild_opu_o.2015-09-22_21/otp_src_18/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
